==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/nl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info niet beschikbaar",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totaal: {memTotalBytes}/Huidig gebruik: {memUsageBytes}",
    "RAM info not available" : "RAM-info niet beschikbaar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totaal: {swapTotalBytes}/Huidig gebruik: {swapUsageBytes}",
    "SWAP info not available" : "SWAP-info niet beschikbaar",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "System" : "Systeem",
    "Monitoring" : "Monitoren",
    "Monitoring app with useful server information" : "Monitor app met nuttige serverinformatie",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Toont nuttige serverinformatie, zoals CPU belasting, RAM gebruik, disk gebruik, aantal gebruikers, etc.",
    "Operating System:" : "Besturingssysteem:",
    "CPU:" : "CPU:",
    "Memory:" : "Geheugen:",
    "Server time:" : "Servertijd:",
    "Uptime:" : "Bedrijfstijd:",
    "Temperature" : "Temperatuur",
    "Load" : "Belasting",
    "Memory" : "Geheugen",
    "Disk" : "Schijf",
    "Mount:" : "Koppelpunt:",
    "Filesystem:" : "Bestandssysteem:",
    "Size:" : "Grootte:",
    "Available:" : "Beschikbaar:",
    "Used:" : "Gebruikt:",
    "Files:" : "Bestanden:",
    "Storages:" : "Opslag:",
    "Free Space:" : "Vrije ruimte:",
    "Network" : "Netwerk",
    "Hostname:" : "Hostname:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Snelheid:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Actieve gebruikers",
    "Last hour" : "Laatste uur",
    "Shares" : "Delen",
    "Users:" : "Gebruikers:",
    "Groups:" : "Groepen:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated verstuurd:",
    "Federated received:" : "Federated ontvangen:",
    "Talk conversations:" : "Talk gesprekken:",
    "PHP" : "PHP",
    "Version:" : "Versie:",
    "Memory limit:" : "Geheugen limiet:",
    "Max execution time:" : "Maximale uitvoeringstijd:",
    "Upload max size:" : "Max. uploadgrootte:",
    "OPcache Revalidate Frequency:" : "Frequentie OPcache opnieuw valideren:",
    "Extensions:" : "Extensies:",
    "Unable to list extensions" : "Kan extensies niet weergeven",
    "Show phpinfo" : "phpinfo weergeven",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Externe monitoring tool",
    "Use this end point to connect an external monitoring tool:" : "Gebruik dit eindpunt om een extern monitoringprogramma te koppelen:",
    "Copy" : "Kopiëren",
    "Output in JSON" : "Uitvoer in JSON",
    "Skip server update" : "Serverupdate overslaan",
    "To use an access token, please generate one then set it using the following command:" : "Om een ​​toegangstoken te gebruiken, genereert u er een en stelt u deze in met de volgende opdracht:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Geef vervolgens het token met de \"NC-Token\" -header door bij het opvragen van de bovenstaande URL.",
    "Unknown Processor" : "Onbekende Processor"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/nl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info niet beschikbaar",
    "CPU Usage:" : "CPU gebruik:",
    "Load average: {percentage} % ({load}) last minute" : "Beladingsgemiddelde: {percentage} % (afgelopen minuut:{load})",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage}% ({lastMinute} Laatste minuut )\n{last5MinutesPercentage}% ({last5Minutes})  Laatste 5 minuten\n{last15MinutesPercentage} % ({last15Minutes}) Laatste 15 minuten",
    "RAM Usage:" : "RAM gebruik:",
    "SWAP Usage:" : "SWAP gebruik;",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totaal: {memTotalBytes}/Huidig gebruik: {memUsageBytes}",
    "RAM info not available" : "RAM-info niet beschikbaar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totaal: {swapTotalBytes}/Huidig gebruik: {swapUsageBytes}",
    "SWAP info not available" : "SWAP-info niet beschikbaar",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "Unknown" : "Onbekend",
    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$ddagen, %2$d uren, %3$d minuten, %4$d seconden",
    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d uren, %2$d minuten, %3$d seconden",
    "System" : "Systeem",
    "Monitoring" : "Monitoren",
    "Monitoring app with useful server information" : "Monitor app met nuttige serverinformatie",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Toont nuttige serverinformatie, zoals CPU belasting, RAM gebruik, disk gebruik, aantal gebruikers, etc.",
    "Operating System:" : "Besturingssysteem:",
    "CPU:" : "CPU:",
    "threads" : "lijnen",
    "Memory:" : "Geheugen:",
    "Server time:" : "Servertijd:",
    "Uptime:" : "Bedrijfstijd:",
    "Temperature" : "Temperatuur",
    "Load" : "Belasting",
    "Memory" : "Geheugen",
    "Disk" : "Schijf",
    "Mount:" : "Koppelpunt:",
    "Filesystem:" : "Bestandssysteem:",
    "Size:" : "Grootte:",
    "Available:" : "Beschikbaar:",
    "Used:" : "Gebruikt:",
    "Files:" : "Bestanden:",
    "Storages:" : "Opslag:",
    "Free Space:" : "Vrije ruimte:",
    "Network" : "Netwerk",
    "Hostname:" : "Hostname:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Snelheid:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Actieve gebruikers",
    "Last hour" : "Laatste uur",
    "%s%% of all users" : "%s %% van alle gebruikers",
    "Last 24 Hours" : "Laatste 24 uur",
    "Last 7 Days" : "Laatste 7 dagen",
    "Last 30 Days" : "Laatste 30 dagen",
    "Shares" : "Delen",
    "Users:" : "Gebruikers:",
    "Groups:" : "Groepen:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated verstuurd:",
    "Federated received:" : "Federated ontvangen:",
    "Talk conversations:" : "Talk gesprekken:",
    "PHP" : "PHP",
    "Version:" : "Versie:",
    "Memory limit:" : "Geheugen limiet:",
    "MB" : "MB",
    "Max execution time:" : "Maximale uitvoeringstijd:",
    "seconds" : "seconden",
    "Upload max size:" : "Max. uploadgrootte:",
    "OPcache Revalidate Frequency:" : "Frequentie OPcache opnieuw valideren:",
    "Extensions:" : "Extensies:",
    "Unable to list extensions" : "Kan extensies niet weergeven",
    "PHP Info:" : "PHP info:",
    "Show phpinfo" : "phpinfo weergeven",
    "FPM worker pool" : "FPM werkpool",
    "Pool name:" : "Poolnaam:",
    "Pool type:" : "Pooltype:",
    "Start time:" : "Starttijd:",
    "Accepted connections:" : "Geaccepteerde verbindingen:",
    "Total processes:" : "Totaal aantal processen:",
    "Active processes:" : "Actieve processen:",
    "Idle processes:" : "Slapende processen:",
    "Listen queue:" : "Luisterwachtrij:",
    "Slow requests:" : "Langzame aanvragen:",
    "Max listen queue:" : "Max luisterwachtrij:",
    "Max active processes:" : "Max actieve processen:",
    "Max children reached:" : "Max kinderen bereikt:",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Externe monitoring tool",
    "Use this end point to connect an external monitoring tool:" : "Gebruik dit eindpunt om een extern monitoringprogramma te koppelen:",
    "Copy" : "Kopiëren",
    "Output in JSON" : "Uitvoer in JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Sla apps sectie over (apps sectie meenemen stuurt een extern verzoek naar de app store)",
    "Skip server update" : "Serverupdate overslaan",
    "To use an access token, please generate one then set it using the following command:" : "Om een ​​toegangstoken te gebruiken, genereert u er een en stelt u deze in met de volgende opdracht:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Geef vervolgens het token met de \"NC-Token\" -header door bij het opvragen van de bovenstaande URL.",
    "Unknown Processor" : "Onbekende Processor"
},
"nplurals=2; plural=(n != 1);");
